module com.github.GitHubAction

abstract class Trigger {
	hidden name: String
}

class Push extends Trigger {
	name: String = "push"
	branches: Listing<String>
}

class WorkflowDispatch extends Trigger {
	name = "workflow_dispatch"
}

abstract class Machine {
	name: String
}
class UbuntuLatestMachine extends Machine {
	name = "ubuntu-latest"
}
class MacOsMachine extends Machine {
	name = "macos-latest"
}
class WindowsMachine extends Machine {
	name = "windows-latest"
}
UbuntuLatest = new UbuntuLatestMachine {} 
MacOsLatest = new MacOsMachine {} 
WindowsLatest = new WindowsMachine {} 

class Job {
	`runs-on`: Machine|String
	steps: Listing<Step>
}

open class Step {
	name: String?
	id: String?
	`if`: String?
}

class RunStep extends Step {
	run: String
}

class UsesStep extends Step {
	uses: String
	with: Mapping<String, String>?
}
